from pygame.sprite import Sprite, OrderedUpdates
from pygame.time import Clock
import pygame
import graphics
from events import TIMER_EXPIRED

class InfoBoardBackground(Sprite):

    def __init__(self, x, y):
        super(InfoBoardBackground, self).__init__()
        self.image = graphics.load_graphic('infoboard')
        self.rect = self.image.get_rect()
        self.rect.move_ip(x, y)

class Timer(Sprite):
    def __init__(self, x, y, timer):
        super(Timer, self).__init__()
        self.timer = timer
        self.pos = (x, y)
        self.update()
        self.clock = Clock()

    def update(self):
        self.image = graphics.render_text(
            "time:   %d sec"%(self.timer.time_remaining/1000), (255,255,255))
        self.rect = self.image.get_rect()
        self.rect.move_ip(self.pos)
        
class Score(Sprite):
    def __init__(self, x, y, score):
        super(Score, self).__init__()
        self.score = score
        self.pos = (x, y)
        self.previous_points = -1
        self.update()

    def update(self):
        if self.score.points != self.previous_points:
            self.image = graphics.render_text(
                "score:   %d"%(self.score.points), (255,255,255))
            self.rect = self.image.get_rect()
            self.rect.move_ip(self.pos)

class BeamEnergy(Sprite):
    def __init__(self, x, y, ufo):
        super(BeamEnergy, self).__init__()
        self.ufo = ufo
        self.pos = (x, y)
        self.update()

    def update(self):
        self.image = graphics.render_text(
            "energy:   %d"%(self.ufo.beam_energy), (255,255,255))
        self.rect = self.image.get_rect()
        self.rect.move_ip(self.pos)



class InfoBoard(OrderedUpdates):

    def __init__(self, x, y, score, timer, ufo):
        super(InfoBoard, self).__init__(self)

        margin = 2

        #self.add(InfoBoardBackground(x, y))
        self.add(Timer(x+margin, y+2, timer))
        self.add(Score(x+margin, y+20, score))
        self.add(BeamEnergy(x+margin, y+40, ufo))

