from pygame.sprite import Sprite, RenderUpdates
from pygame.time import Clock
import pygame
import graphics
import math
import random
from events import *
from target import Target

class CargoShip(Target):
    def __init__(self, destinations):
        super(CargoShip, self).__init__(
            'cargo',
            speed=60,
            beamtime=2,
            destinations=destinations,
            score=10)

class AirCraftCarrier(Target):
    def __init__(self, destinations):
        super(AirCraftCarrier, self).__init__(
            'carrier',
            speed=40,
            beamtime=3,
            destinations=destinations,
            score=15)

class ShipGenerator(RenderUpdates):
    paths = [
        [(1380, 1024), (1000, 900), (1000, 400), (900, 300), (100, 300)],
        [(0, 830), (800, 900), (880, 1080)],
        [(1300, 80), (550, 80), (525, 125), (525, 150), (550, 175), (1300, 450)],
        [(370, -40), (370, 480), (1300, 200)],        
        ]

    ship_factories = [CargoShip, AirCraftCarrier]
    
    def __init__(self):
        super(ShipGenerator, self).__init__()
        self.current_path = 0
        self.clock = Clock()
        self.time_passed = 0

    def update(self):
        self.time_passed += self.clock.tick()
        
        if len(self.sprites())<=4 and self.time_passed>2000:
            ship = self.ship_factories[random.randint(0, len(self.ship_factories)-1)]
            self.add(ship(self.paths[self.current_path]))
            self.current_path += 1
            if self.current_path>=len(self.paths):
                self.current_path = 0
            self.time_passed = 0

        super(ShipGenerator, self).update()
    



    
        
