from pygame.sprite import Sprite, RenderUpdates
from pygame.time import Clock
import pygame
import graphics
import math
import random
from events import *

_movement = {
    0:(0,1),
    1:(1,1),
    2:(1,0),
    3:(1,-1),
    4:(0,-1),
    -3:(-1,-1),
    -2:(-1,0),
    -1:(-1,1)}
    

class Target(Sprite):
    
    def __init__(self, image_name, speed,
                 beamtime, destinations, score):
        """Create a target

        speed = pixels / second"""
        
        super(Target, self).__init__()
        
        self.images = dict([(i, graphics.load_graphic(
            '%s-%d'%(image_name, i))) for i in range(-3, 5)])
        self.rect = self.images[0].get_rect()
        self.rect.center = destinations[0]

        # movement stuff
        self.speed = speed
        self.destinations = destinations[1:]

        # beam related stuff
        self.beamtime = beamtime
        self.time_in_beam = 0
        self.in_target_beam = False

        self.clock = Clock()
        self.timepassed = 0

        self.direction = 0

        self.score = score
        
    def update(self):
        self.timepassed += self.clock.tick()

        if self.in_target_beam:
            if (self.timepassed/1000)>self.beamtime:
                pygame.event.post(
                    pygame.event.Event(TARGET_CAPTURED, target=self))
                self.kill()

        else:
            while (self.timepassed > 1000/self.speed) and self.destinations:
                self.move()
                self.timepassed -= 1000/self.speed

        self.image = self.images[self.direction]
        oldrect = self.rect
        self.rect = self.image.get_rect()
        self.rect.center = oldrect.center

    def move(self):
        destination = self.destinations[0]
        x_difference = destination[0] - self.rect.centerx
        y_difference = destination[1] - self.rect.centery

        angle = math.degrees(
            math.atan2(x_difference, y_difference))
        self.direction = int(angle/45)

        self.rect.move_ip(_movement[self.direction])

        if(self.rect.center==self.destinations[0]):
            del self.destinations[0]
            if len(self.destinations)==0:
                self.kill()

    def lock_in_beam(self):
        self.in_target_beam = True
        self.timepassed = 0

    def release_beam_lock(self):
        self.timepassed = 0
        self.in_target_beam = False
        

